==> unit-1.0.31-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractRolesTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractRolesTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public RolesTemplate.Header. _9_2_11339642018 _9_2_11339642018;
	public RolesTemplate.Header._9_2_11339642018. _10_3_01249520959 _10_3_01249520959;
	public RolesTemplate.Header._9_2_11339642018._10_3_01249520959. _11_4_02075283838 _11_4_02075283838;
	public RolesTemplate.Header._9_2_11339642018. Count count;
	public RolesTemplate.Header. RightToolbar rightToolbar;
	public RolesTemplate.Header.RightToolbar. Search search;
	public RolesTemplate.Header.RightToolbar. Download download;
	public RolesTemplate.Header.RightToolbar. Filters filters;
	public _18_1_1366070726 _18_1_1366070726;
	public RolesTemplate._18_1_1366070726. _19_2_11650325332 _19_2_11650325332;
	public RolesToolbarTemplate toolbar;
	public RolesTemplate._18_1_1366070726._19_2_11650325332. _21_3_0424019081 _21_3_0424019081;
	public RolesTemplate._18_1_1366070726._19_2_11650325332._21_3_0424019081. TableView tableView;
	public RolesTableCatalog tableViewStamp;
	public RolesTemplate._18_1_1366070726. FiltersView filtersView;
	public RolesFiltersTemplate rolesFiltersStamp;
	public RolesTemplate._18_1_1366070726. RoleView roleView;
	public RoleEmbeddedTemplate roleStamp;

    public AbstractRolesTemplate(B box) {
        super(box);
        id("rolesTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header(box()).<Header>id("a2090485844").owner(AbstractRolesTemplate.this));
		if (header != null) _9_2_11339642018 = header._9_2_11339642018;
		if (_9_2_11339642018 != null) _10_3_01249520959 = header._9_2_11339642018._10_3_01249520959;
		if (_10_3_01249520959 != null) _11_4_02075283838 = header._9_2_11339642018._10_3_01249520959._11_4_02075283838;
		if (_9_2_11339642018 != null) count = header._9_2_11339642018.count;
		if (header != null) rightToolbar = header.rightToolbar;
		if (rightToolbar != null) search = header.rightToolbar.search;
		if (rightToolbar != null) download = header.rightToolbar.download;
		if (rightToolbar != null) filters = header.rightToolbar.filters;
		if (_18_1_1366070726 == null) _18_1_1366070726 = register(new _18_1_1366070726(box()).<_18_1_1366070726>id("a1130123938").owner(AbstractRolesTemplate.this));
		if (_18_1_1366070726 != null) _19_2_11650325332 = _18_1_1366070726._19_2_11650325332;
		if (_19_2_11650325332 != null) toolbar = _18_1_1366070726._19_2_11650325332.toolbar;
		if (_19_2_11650325332 != null) _21_3_0424019081 = _18_1_1366070726._19_2_11650325332._21_3_0424019081;
		if (_21_3_0424019081 != null) tableView = _18_1_1366070726._19_2_11650325332._21_3_0424019081.tableView;
		if (tableView != null) tableViewStamp = _18_1_1366070726._19_2_11650325332._21_3_0424019081.tableView.tableViewStamp;
		if (_18_1_1366070726 != null) filtersView = _18_1_1366070726.filtersView;
		if (filtersView != null) rolesFiltersStamp = _18_1_1366070726.filtersView.rolesFiltersStamp;
		if (_18_1_1366070726 != null) roleView = _18_1_1366070726.roleView;
		if (roleView != null) roleStamp = _18_1_1366070726.roleView.roleStamp;
	}

	public class Header extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public RolesTemplate.Header. _9_2_11339642018 _9_2_11339642018;
		public RolesTemplate.Header. RightToolbar rightToolbar;

		public Header(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_9_2_11339642018 == null) _9_2_11339642018 = register(new _9_2_11339642018(box()).<_9_2_11339642018>id("a497273301").owner(AbstractRolesTemplate.this));
			if (rightToolbar == null) rightToolbar = register(new RightToolbar(box()).<RightToolbar>id("a_2091953206").owner(AbstractRolesTemplate.this));
		}

		public class _9_2_11339642018 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public RolesTemplate.Header._9_2_11339642018. _10_3_01249520959 _10_3_01249520959;
			public RolesTemplate.Header._9_2_11339642018. Count count;

			public _9_2_11339642018(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_10_3_01249520959 == null) _10_3_01249520959 = register(new _10_3_01249520959(box()).<_10_3_01249520959>id("a_2136793890").owner(AbstractRolesTemplate.this));
				if (count == null) count = register(new Count(box()).<Count>id("a1985240474").owner(AbstractRolesTemplate.this));
			}

			public class _10_3_01249520959 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public RolesTemplate.Header._9_2_11339642018._10_3_01249520959. _11_4_02075283838 _11_4_02075283838;

				public _10_3_01249520959(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_11_4_02075283838 == null) _11_4_02075283838 = register(new _11_4_02075283838(box()).<_11_4_02075283838>id("a515986247").owner(AbstractRolesTemplate.this));
				}

				public class _11_4_02075283838 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _11_4_02075283838(B box) {
						super(box);
						_value("Roles");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}

			public class Count extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Count(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class RightToolbar extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public RolesTemplate.Header.RightToolbar. Search search;
			public RolesTemplate.Header.RightToolbar. Download download;
			public RolesTemplate.Header.RightToolbar. Filters filters;

			public RightToolbar(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (search == null) search = register(new Search(box()).<Search>id("a1517623229").owner(AbstractRolesTemplate.this));
				if (download == null) download = register(new Download(box()).<Download>id("a_1313781411").owner(AbstractRolesTemplate.this));
				if (filters == null) filters = register(new Filters(box()).<Filters>id("a1273771142").owner(AbstractRolesTemplate.this));
			}

			public class Search extends io.intino.alexandria.ui.displays.components.SearchBox<io.intino.alexandria.ui.displays.notifiers.SearchBoxNotifier, B>  {

				public Search(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class Download extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

				public Download(B box) {
					super(box);
					_title("Download");
					_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
					_icon("Archive");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class Filters extends io.intino.alexandria.ui.displays.components.ActionToggle<io.intino.alexandria.ui.displays.notifiers.ActionToggleNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

				public Filters(B box) {
					super(box);
					_title("Filtrar");
					_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconToggle"));
					_icon("FilterList");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}

	public class _18_1_1366070726 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public RolesTemplate._18_1_1366070726. _19_2_11650325332 _19_2_11650325332;
		public RolesTemplate._18_1_1366070726. FiltersView filtersView;
		public RolesTemplate._18_1_1366070726. RoleView roleView;

		public _18_1_1366070726(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_19_2_11650325332 == null) _19_2_11650325332 = register(new _19_2_11650325332(box()).<_19_2_11650325332>id("a492764164").owner(AbstractRolesTemplate.this));
			if (filtersView == null) filtersView = register(new FiltersView(box()).<FiltersView>id("a_1703726212").owner(AbstractRolesTemplate.this));
			if (roleView == null) roleView = register(new RoleView(box()).<RoleView>id("a_1622624385").owner(AbstractRolesTemplate.this));
		}

		public class _19_2_11650325332 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public RolesToolbarTemplate toolbar;
			public RolesTemplate._18_1_1366070726._19_2_11650325332. _21_3_0424019081 _21_3_0424019081;

			public _19_2_11650325332(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (toolbar == null) toolbar = register(new RolesToolbarTemplate((UnitBox)box()).id("a199459193"));
				if (_21_3_0424019081 == null) _21_3_0424019081 = register(new _21_3_0424019081(box()).<_21_3_0424019081>id("a1318819750").owner(AbstractRolesTemplate.this));
			}

			public class _21_3_0424019081 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public RolesTemplate._18_1_1366070726._19_2_11650325332._21_3_0424019081. TableView tableView;

				public _21_3_0424019081(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (tableView == null) tableView = register(new TableView(box()).<TableView>id("a1171720809").owner(AbstractRolesTemplate.this));
				}

				public class TableView extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
					public RolesTableCatalog tableViewStamp;

					public TableView(B box) {
						super(box);
					}

					@Override
					public void initConditional() {
						super.init();
						if (tableViewStamp == null) tableViewStamp = register(new RolesTableCatalog((UnitBox)box()).id("a_170530682"));
						if (tableViewStamp == null) tableViewStamp = _18_1_1366070726._19_2_11650325332._21_3_0424019081.tableView.tableViewStamp;
					}
				}
			}
		}

		public class FiltersView extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public RolesFiltersTemplate rolesFiltersStamp;

			public FiltersView(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (rolesFiltersStamp == null) rolesFiltersStamp = register(new RolesFiltersTemplate((UnitBox)box()).id("a661182946"));
				if (rolesFiltersStamp == null) rolesFiltersStamp = _18_1_1366070726.filtersView.rolesFiltersStamp;
			}
		}

		public class RoleView extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public RoleEmbeddedTemplate roleStamp;

			public RoleView(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (roleStamp == null) roleStamp = register(new RoleEmbeddedTemplate((UnitBox)box()).id("a958647341"));
				if (roleStamp == null) roleStamp = _18_1_1366070726.roleView.roleStamp;
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractRolesTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractRolesTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public RolesTemplate.Header. _9_2_11339642018 _9_2_11339642018;
	public RolesTemplate.Header._9_2_11339642018. _10_3_01249520959 _10_3_01249520959;
	public RolesTemplate.Header._9_2_11339642018._10_3_01249520959. _11_4_02075283838 _11_4_02075283838;
	public RolesTemplate.Header._9_2_11339642018. Count count;
	public RolesTemplate.Header. RightToolbar rightToolbar;
	public RolesTemplate.Header.RightToolbar. Search search;
	public RolesTemplate.Header.RightToolbar. Download download;
	public RolesTemplate.Header.RightToolbar. Filters filters;
	public _18_1_1366070726 _18_1_1366070726;
	public RolesTemplate._18_1_1366070726. _19_2_11650325332 _19_2_11650325332;
	public RolesToolbarTemplate toolbar;
	public RolesTemplate._18_1_1366070726._19_2_11650325332. _21_3_0424019081 _21_3_0424019081;
	public RolesTemplate._18_1_1366070726._19_2_11650325332._21_3_0424019081. TableView tableView;
	public RolesTableCatalog tableViewStamp;
	public RolesTemplate._18_1_1366070726. FiltersView filtersView;
	public RolesFiltersTemplate rolesFiltersStamp;
	public RolesTemplate._18_1_1366070726. RoleView roleView;
	public RoleEmbeddedTemplate roleStamp;

    public AbstractRolesTemplate(B box) {
        super(box);
        id("rolesTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header(box()).<Header>id("a2090485844").owner(AbstractRolesTemplate.this));
		if (header != null) _9_2_11339642018 = header._9_2_11339642018;
		if (_9_2_11339642018 != null) _10_3_01249520959 = header._9_2_11339642018._10_3_01249520959;
		if (_10_3_01249520959 != null) _11_4_02075283838 = header._9_2_11339642018._10_3_01249520959._11_4_02075283838;
		if (_9_2_11339642018 != null) count = header._9_2_11339642018.count;
		if (header != null) rightToolbar = header.rightToolbar;
		if (rightToolbar != null) search = header.rightToolbar.search;
		if (rightToolbar != null) download = header.rightToolbar.download;
		if (rightToolbar != null) filters = header.rightToolbar.filters;
		if (_18_1_1366070726 == null) _18_1_1366070726 = register(new _18_1_1366070726(box()).<_18_1_1366070726>id("a1130123938").owner(AbstractRolesTemplate.this));
		if (_18_1_1366070726 != null) _19_2_11650325332 = _18_1_1366070726._19_2_11650325332;
		if (_19_2_11650325332 != null) toolbar = _18_1_1366070726._19_2_11650325332.toolbar;
		if (_19_2_11650325332 != null) _21_3_0424019081 = _18_1_1366070726._19_2_11650325332._21_3_0424019081;
		if (_21_3_0424019081 != null) tableView = _18_1_1366070726._19_2_11650325332._21_3_0424019081.tableView;
		if (tableView != null) tableViewStamp = _18_1_1366070726._19_2_11650325332._21_3_0424019081.tableView.tableViewStamp;
		if (_18_1_1366070726 != null) filtersView = _18_1_1366070726.filtersView;
		if (filtersView != null) rolesFiltersStamp = _18_1_1366070726.filtersView.rolesFiltersStamp;
		if (_18_1_1366070726 != null) roleView = _18_1_1366070726.roleView;
		if (roleView != null) roleStamp = _18_1_1366070726.roleView.roleStamp;
	}

    @Override
    public void remove() {
        super.remove();
	    if (header != null) header.unregister();
	    if (_18_1_1366070726 != null) _18_1_1366070726.unregister();
	}

	public class Header extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public RolesTemplate.Header. _9_2_11339642018 _9_2_11339642018;
		public RolesTemplate.Header. RightToolbar rightToolbar;

		public Header(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_9_2_11339642018 == null) _9_2_11339642018 = register(new _9_2_11339642018(box()).<_9_2_11339642018>id("a497273301").owner(AbstractRolesTemplate.this));
			if (rightToolbar == null) rightToolbar = register(new RightToolbar(box()).<RightToolbar>id("a_2091953206").owner(AbstractRolesTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_9_2_11339642018 != null) _9_2_11339642018.unregister();
			if (rightToolbar != null) rightToolbar.unregister();
		}

		public class _9_2_11339642018 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public RolesTemplate.Header._9_2_11339642018. _10_3_01249520959 _10_3_01249520959;
			public RolesTemplate.Header._9_2_11339642018. Count count;

			public _9_2_11339642018(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_10_3_01249520959 == null) _10_3_01249520959 = register(new _10_3_01249520959(box()).<_10_3_01249520959>id("a_2136793890").owner(AbstractRolesTemplate.this));
				if (count == null) count = register(new Count(box()).<Count>id("a1985240474").owner(AbstractRolesTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_10_3_01249520959 != null) _10_3_01249520959.unregister();
				if (count != null) count.unregister();
			}

			public class _10_3_01249520959 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public RolesTemplate.Header._9_2_11339642018._10_3_01249520959. _11_4_02075283838 _11_4_02075283838;

				public _10_3_01249520959(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_11_4_02075283838 == null) _11_4_02075283838 = register(new _11_4_02075283838(box()).<_11_4_02075283838>id("a515986247").owner(AbstractRolesTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (_11_4_02075283838 != null) _11_4_02075283838.unregister();
				}

				public class _11_4_02075283838 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _11_4_02075283838(B box) {
						super(box);
						_value("Roles");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}

			public class Count extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Count(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class RightToolbar extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public RolesTemplate.Header.RightToolbar. Search search;
			public RolesTemplate.Header.RightToolbar. Download download;
			public RolesTemplate.Header.RightToolbar. Filters filters;

			public RightToolbar(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (search == null) search = register(new Search(box()).<Search>id("a1517623229").owner(AbstractRolesTemplate.this));
				if (download == null) download = register(new Download(box()).<Download>id("a_1313781411").owner(AbstractRolesTemplate.this));
				if (filters == null) filters = register(new Filters(box()).<Filters>id("a1273771142").owner(AbstractRolesTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (search != null) search.unregister();
				if (download != null) download.unregister();
				if (filters != null) filters.unregister();
			}

			public class Search extends io.intino.alexandria.ui.displays.components.SearchBox<io.intino.alexandria.ui.displays.notifiers.SearchBoxNotifier, B>  {

				public Search(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class Download extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

				public Download(B box) {
					super(box);
					_title("Download");
					_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
					_icon("Archive");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class Filters extends io.intino.alexandria.ui.displays.components.ActionToggle<io.intino.alexandria.ui.displays.notifiers.ActionToggleNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

				public Filters(B box) {
					super(box);
					_title("Filtrar");
					_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconToggle"));
					_icon("FilterList");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}

	public class _18_1_1366070726 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public RolesTemplate._18_1_1366070726. _19_2_11650325332 _19_2_11650325332;
		public RolesTemplate._18_1_1366070726. FiltersView filtersView;
		public RolesTemplate._18_1_1366070726. RoleView roleView;

		public _18_1_1366070726(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_19_2_11650325332 == null) _19_2_11650325332 = register(new _19_2_11650325332(box()).<_19_2_11650325332>id("a492764164").owner(AbstractRolesTemplate.this));
			if (filtersView == null) filtersView = register(new FiltersView(box()).<FiltersView>id("a_1703726212").owner(AbstractRolesTemplate.this));
			if (roleView == null) roleView = register(new RoleView(box()).<RoleView>id("a_1622624385").owner(AbstractRolesTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_19_2_11650325332 != null) _19_2_11650325332.unregister();
			if (filtersView != null) filtersView.unregister();
			if (roleView != null) roleView.unregister();
		}

		public class _19_2_11650325332 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public RolesToolbarTemplate toolbar;
			public RolesTemplate._18_1_1366070726._19_2_11650325332. _21_3_0424019081 _21_3_0424019081;

			public _19_2_11650325332(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (toolbar == null) toolbar = register(new RolesToolbarTemplate((UnitBox)box()).id("a199459193"));
				if (_21_3_0424019081 == null) _21_3_0424019081 = register(new _21_3_0424019081(box()).<_21_3_0424019081>id("a1318819750").owner(AbstractRolesTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (toolbar != null) toolbar.unregister();
				if (_21_3_0424019081 != null) _21_3_0424019081.unregister();
			}

			public class _21_3_0424019081 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public RolesTemplate._18_1_1366070726._19_2_11650325332._21_3_0424019081. TableView tableView;

				public _21_3_0424019081(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (tableView == null) tableView = register(new TableView(box()).<TableView>id("a1171720809").owner(AbstractRolesTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (tableView != null) tableView.unregister();
				}

				public class TableView extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
					public RolesTableCatalog tableViewStamp;

					public TableView(B box) {
						super(box);
					}

					@Override
					public void initConditional() {
						super.init();
						if (tableViewStamp == null) tableViewStamp = register(new RolesTableCatalog((UnitBox)box()).id("a_170530682"));
						if (tableViewStamp == null) tableViewStamp = _18_1_1366070726._19_2_11650325332._21_3_0424019081.tableView.tableViewStamp;
					}

					@Override
					public void unregister() {
					    super.unregister();
						if (tableViewStamp != null) tableViewStamp.unregister();
					}
				}
			}
		}

		public class FiltersView extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public RolesFiltersTemplate rolesFiltersStamp;

			public FiltersView(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (rolesFiltersStamp == null) rolesFiltersStamp = register(new RolesFiltersTemplate((UnitBox)box()).id("a661182946"));
				if (rolesFiltersStamp == null) rolesFiltersStamp = _18_1_1366070726.filtersView.rolesFiltersStamp;
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (rolesFiltersStamp != null) rolesFiltersStamp.unregister();
			}
		}

		public class RoleView extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public RoleEmbeddedTemplate roleStamp;

			public RoleView(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (roleStamp == null) roleStamp = register(new RoleEmbeddedTemplate((UnitBox)box()).id("a958647341"));
				if (roleStamp == null) roleStamp = _18_1_1366070726.roleView.roleStamp;
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (roleStamp != null) roleStamp.unregister();
			}
		}
	}
}
